==> haskell-edisoncore-1.3.2.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonCore
version: 1.3.2.1
id: EdisonCore-1.3.2.1-DoXlfXQyQE6FEadsUjNsA5
key: EdisonCore-1.3.2.1-DoXlfXQyQE6FEadsUjNsA5
license: MIT
maintainer: robdockins AT fastmail DOT fm
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (Core Implementations)
description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.
category: Data Structures
author: Chris Okasaki
exposed: True
indefinite: False
exposed-modules:
    Data.Edison.Assoc.AssocList Data.Edison.Assoc.Defaults
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Coll.Defaults
    Data.Edison.Coll.EnumSet Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.UnbalancedSet
    Data.Edison.Concrete.FingerTree Data.Edison.Seq.BankersQueue
    Data.Edison.Seq.BinaryRandList Data.Edison.Seq.BraunSeq
    Data.Edison.Seq.Defaults Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq
abi: 62aa65f4b64a99273eec3faa95aa6e16
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/EdisonCore-1.3.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/EdisonCore-1.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/EdisonCore-1.3.2.1
hs-libraries: HSEdisonCore-1.3.2.1-DoXlfXQyQE6FEadsUjNsA5
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9
    EdisonAPI-1.3.1-1akndpBptKO3wS8UCq7mqi containers-0.5.10.2
    array-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             EdisonAPI-1.3.1-1akndpBptKO3wS8UCq7mqi=64f70a87dbc9629d563924967b81a73a
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
haddock-interfaces: /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html: /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edisoncore-1.3.2.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonCore
version: 1.3.2.1
id: EdisonCore-1.3.2.1-4DiYsSPnxWPHOxgPBfawSH
key: EdisonCore-1.3.2.1-4DiYsSPnxWPHOxgPBfawSH
license: MIT
maintainer: robdockins AT fastmail DOT fm
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (Core Implementations)
description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.
category: Data Structures
author: Chris Okasaki
exposed: True
indefinite: False
exposed-modules:
    Data.Edison.Assoc.AssocList Data.Edison.Assoc.Defaults
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Coll.Defaults
    Data.Edison.Coll.EnumSet Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.UnbalancedSet
    Data.Edison.Concrete.FingerTree Data.Edison.Seq.BankersQueue
    Data.Edison.Seq.BinaryRandList Data.Edison.Seq.BraunSeq
    Data.Edison.Seq.Defaults Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq
abi: 0c4a4cd69a969da0b2c956ef958d177a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/EdisonCore-1.3.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/EdisonCore-1.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/EdisonCore-1.3.2.1
hs-libraries: HSEdisonCore-1.3.2.1-4DiYsSPnxWPHOxgPBfawSH
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9
    EdisonAPI-1.3.1-IaG6hy9pPqn2w7z99RdxUC containers-0.5.10.2
    array-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             EdisonAPI-1.3.1-IaG6hy9pPqn2w7z99RdxUC=980cab4f4eded17706a2e2838b706a46
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
haddock-interfaces: /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html: /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
